==> kubernetes-client-4.10.3-sources.jar: io/fabric8/kubernetes/client/handlers/metrics/v1beta1/NodeMetricsHandler.java <==

                                          

package io.fabric8.kubernetes.client.handlers.metrics.v1beta1;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.kubernetes.client.dsl.internal.metrics.v1beta1.NodeMetricsOperationsImpl;

import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetrics;
import io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class NodeMetricsHandler implements ResourceHandler<NodeMetrics, NodeMetricsBuilder> {

  @Override
  public String getKind() {
    return NodeMetrics.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
        return "metrics.k8s.io/v1beta1";
      }

  @Override
  public NodeMetrics create(OkHttpClient client, Config config, String namespace, NodeMetrics item) {
    return new NodeMetricsOperationsImpl(client, config).withItem(item).inNamespace(namespace).create();
  }

  @Override
  public NodeMetrics replace(OkHttpClient client, Config config, String namespace, NodeMetrics item) {
    return new NodeMetricsOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).replace(item);
  }

  @Override
  public NodeMetrics reload(OkHttpClient client, Config config, String namespace, NodeMetrics item) {
    return new NodeMetricsOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public NodeMetricsBuilder edit(NodeMetrics item) {
    return new NodeMetricsBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, NodeMetrics item) {
    return new NodeMetricsOperationsImpl(client, config, namespace).withItem(item).withPropagationPolicy(propagationPolicy).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, NodeMetrics item, Watcher<NodeMetrics> watcher) {
    return new NodeMetricsOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, NodeMetrics item, String resourceVersion, Watcher<NodeMetrics> watcher) {
    return new NodeMetricsOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, NodeMetrics item, ListOptions options, Watcher<NodeMetrics> watcher) {
    return new NodeMetricsOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }

  @Override
  public NodeMetrics waitUntilReady(OkHttpClient client, Config config, String namespace, NodeMetrics item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new NodeMetricsOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public NodeMetrics waitUntilCondition(OkHttpClient client, Config config, String namespace, NodeMetrics item, Predicate<NodeMetrics> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new NodeMetricsOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}

==> kubernetes-client-5.3.1-sources.jar: io/fabric8/kubernetes/client/handlers/metrics/v1beta1/NodeMetricsHandler.java <==

                                          

package io.fabric8.kubernetes.client.handlers.metrics.v1beta1;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.kubernetes.client.dsl.internal.metrics.v1beta1.NodeMetricsOperationsImpl;

import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetrics;
import io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class NodeMetricsHandler implements ResourceHandler<NodeMetrics, NodeMetricsBuilder> {

  @Override
  public String getKind() {
    return NodeMetrics.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
        return "metrics.k8s.io/v1beta1";
      }

  @Override
  public NodeMetrics create(OkHttpClient client, Config config, String namespace, NodeMetrics item, boolean dryRun) {
    return new NodeMetricsOperationsImpl(client, config).withItem(item).inNamespace(namespace).dryRun(dryRun).create();
  }

  @Override
  public NodeMetrics replace(OkHttpClient client, Config config, String namespace, NodeMetrics item, boolean dryRun) {
    return new NodeMetricsOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).dryRun(dryRun).replace(item);
  }

  @Override
  public NodeMetrics reload(OkHttpClient client, Config config, String namespace, NodeMetrics item) {
    return new NodeMetricsOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public NodeMetricsBuilder edit(NodeMetrics item) {
    return new NodeMetricsBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, long gracePeriodSeconds, NodeMetrics item, boolean dryRun) {
    return new NodeMetricsOperationsImpl(client, config, namespace).withItem(item).dryRun(dryRun).withPropagationPolicy(propagationPolicy).withGracePeriod(gracePeriodSeconds).delete();
  }

@Override
  public Watch watch(OkHttpClient client, Config config, String namespace, NodeMetrics item, Watcher<NodeMetrics> watcher) {
    return new NodeMetricsOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, NodeMetrics item, String resourceVersion, Watcher<NodeMetrics> watcher) {
    return new NodeMetricsOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, NodeMetrics item, ListOptions options, Watcher<NodeMetrics> watcher) {
    return new NodeMetricsOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }

  @Override
  public NodeMetrics waitUntilReady(OkHttpClient client, Config config, String namespace, NodeMetrics item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new NodeMetricsOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public NodeMetrics waitUntilCondition(OkHttpClient client, Config config, String namespace, NodeMetrics item, Predicate<NodeMetrics> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new NodeMetricsOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}
